@@ -1,5 +1,5 @@
-/* SPDX-License-Identifier: GPL-2.0 */
-/* Copyright(c) 2013 - 2023 Intel Corporation. */
+/* SPDX-License-Identifier: GPL-2.0-only */
+/* Copyright (C) 2013-2023 Intel Corporation */
 
 #ifndef _KCOMPAT_SLES_DEFS_H_
 #define _KCOMPAT_SLES_DEFS_H_
@@ -70,12 +70,6 @@
  * possible.
  */
 
-/*****************************************************************************/
-#if (SLE_KERNEL_CODE < SLE_KERNEL_VERSION(4,4,0,73))
-#else /* >= 4.4.0-73 */
-#define HAVE_DEVLINK_PORT_SPLIT
-#endif /* 4.4.0-73 */
-
 /*****************************************************************************/
 #if (SLE_KERNEL_CODE > SLE_KERNEL_VERSION(4,12,14,23) && \
      SLE_KERNEL_CODE < SLE_KERNEL_VERSION(4,12,14,94))
@@ -121,7 +115,6 @@
 #undef NEED_MACVLAN_RELEASE_L2FW_OFFLOAD
 #undef NEED_MACVLAN_SUPPORTS_DEST_FILTER
 #undef NEED_IDA_ALLOC_MIN_MAX_RANGE_FREE
-#define HAVE_DEVLINK_PORT_SPLIT_EXTACK
 #endif /* 4.12.14-111 */
 
 /*****************************************************************************/
@@ -149,18 +142,12 @@
 /*****************************************************************************/
 #if (SLE_KERNEL_CODE < SLE_KERNEL_VERSION(5,3,8,2))
 #else /* >= 5.3.8-2 */
-#undef NEED_BUS_FIND_DEVICE_CONST_DATA
 #undef NEED_FLOW_INDR_BLOCK_CB_REGISTER
 #undef NEED_SKB_FRAG_OFF
 #undef NEED_SKB_FRAG_OFF_ADD
 #define HAVE_FLOW_INDR_BLOCK_LOCK
 #endif /* 5.3.8-2 */
 
-#if (SLE_KERNEL_CODE < SLE_KERNEL_VERSION(5,3,18,24))
-#else /* >= 5.3.18-24 */
-#undef NEED_MUL_U64_U64_DIV_U64
-#endif
-
 #if (SLE_KERNEL_CODE < SLE_KERNEL_VERSION(5,3,18,26))
 #else /* >= 5.3.18-26 */
 #undef NEED_CPU_LATENCY_QOS_RENAME
@@ -173,12 +160,6 @@
 #undef NEED_DEVLINK_PORT_ATTRS_SET_STRUCT
 #endif /* 5.3.18-34 */
 
-/*****************************************************************************/
-#if (SLE_KERNEL_CODE < SLE_KERNEL_VERSION(5,3,18,37))
-#else /* >= 5.3.18-37 */
-#undef NEED_NET_PREFETCH
-#endif /* 5.3.18-37 */
-
 /*****************************************************************************/
 #if (SLE_KERNEL_CODE < SLE_KERNEL_VERSION(5,3,18,38))
 #else /* >= 5.3.18-38 */
@@ -197,12 +178,6 @@
 #define HAVE_MEM_TYPE_XSK_BUFF_POOL
 #endif /* 5.3.18-41 */
 
-/*****************************************************************************/
-#if (SLE_KERNEL_CODE < SLE_KERNEL_VERSION(5, 14, 17, 1))
-#else /* >= 5.14.17-150400.1 */
-	#undef NEED_ETHTOOL_SPRINTF
-#endif /* 5.14.17-150400.1 */
-
 /*****************************************************************************/
 #if (SLE_KERNEL_CODE < SLE_KERNEL_VERSION(5,14,21,9))
 #else /* >= 5.14.21-150400.9 */
